@@ -155,7 +155,7 @@ class MainLog(BaseLog):
                                           response_content=str_ret,
                                           response_time=response_time,
                                           response_code=response_code,
-                                          http_status_code=ret.status,
+                                          http_status_code=ret.status_code,
                                           total_time=total_time,
                                           order_id=order_id,
                                           phone_num=phone_num,
